@@ -214,6 +214,8 @@ pub fn functions() -> HashSet<&'static str>
         "inter",
         "interpolate",
         "unity",
+        "iter",
+        "weighted",
     ]
     .iter()
     .cloned()
