@@ -496,7 +496,7 @@ pub fn place_varxy(mut func: Vec<NumStr>, num: NumStr) -> Vec<NumStr>
                     }
                     "sum" | "summation" | "prod" | "product" | "Σ" | "Π" | "vec" | "mat" | "D"
                     | "integrate" | "arclength" | "∫" | "area" | "solve" | "length" | "slope"
-                    | "lim" | "limit"
+                    | "lim" | "limit" | "iter"
                         if i + 2 < func.len()
                             && if let Str(s) = &func[i + 2]
                             {
@@ -544,7 +544,7 @@ pub fn place_var(mut func: Vec<NumStr>, var: &str, num: NumStr) -> Vec<NumStr>
                     }
                     "sum" | "summation" | "prod" | "product" | "Σ" | "Π" | "vec" | "mat" | "D"
                     | "integrate" | "arclength" | "∫" | "area" | "solve" | "length" | "slope"
-                    | "lim" | "limit"
+                    | "lim" | "limit" | "iter"
                         if i + 2 < func.len() && func[i + 2] == Str(var.to_string()) =>
                     {
                         i += 3;
